@@ -1,6 +1,6 @@
 /*
  *  Phusion Passenger - https://www.phusionpassenger.com/
- *  Copyright (c) 2010-2016 Phusion Holding B.V.
+ *  Copyright (c) 2010-2017 Phusion Holding B.V.
  *
  *  "Passenger", "Phusion Passenger" and "Union Station" are registered
  *  trademarks of Phusion Holding B.V.
@@ -58,10 +58,10 @@
 #include <Utils.h>
 #include <Utils/IOUtils.h>
 #include <Utils/StrIntUtils.h>
-#include <Utils/Timer.h>
+#include <Utils/SystemTime.h>
 #include <Utils/HttpConstants.h>
 #include <Utils/ReleaseableScopedPointer.h>
-#include <Logging.h>
+#include <LoggingKit/LoggingKit.h>
 #include <WatchdogLauncher.h>
 #include <Constants.h>
 
@@ -314,19 +314,6 @@ private:
 		return conn;
 	}
 
-	vector<string> getConfigFiles(server_rec *s) const {
-		server_rec *server;
-		vector<string> result;
-
-		for (server = s; server != NULL; server = server->next) {
-			if (server->defn_name != NULL) {
-				result.push_back(server->defn_name);
-			}
-		}
-
-		return result;
-	}
-
 	bool hasModRewrite() {
 		if (m_hasModRewrite == UNKNOWN) {
 			if (ap_find_linked_module("mod_rewrite.c")) {
@@ -580,8 +567,8 @@ private:
 				return httpStatus;
 			}
 
-			this_thread::disable_interruption di;
-			this_thread::disable_syscall_interruption dsi;
+			boost::this_thread::disable_interruption di;
+			boost::this_thread::disable_syscall_interruption dsi;
 			bool expectingBody;
 
 			expectingBody = ap_should_client_block(r);
@@ -630,7 +617,6 @@ private:
 			 * util_script.c's source. :-(
 			 */
 			char backendData[MAX_STRING_LEN];
-			Timer timer;
 			getsfunc_BRIGADE(backendData, MAX_STRING_LEN, bb);
 
 			// The bucket brigade is an interface to the HTTP response sent by the
@@ -1253,20 +1239,33 @@ public:
 	{
 		passenger_postprocess_config(s);
 
-		Passenger::setLogLevel(serverConfig.logLevel);
+		Json::Value loggingConfig;
+		loggingConfig["level"] = LoggingKit::Level(serverConfig.logLevel);
+		loggingConfig["redirect_stderr"] = false;
 		if (serverConfig.logFile != NULL) {
-			int errcode;
-			if (!Passenger::setLogFileWithoutRedirectingStderr(serverConfig.logFile, &errcode)) {
-				fprintf(stderr,
-					"ERROR: cannot open log file %s: %s (errno=%d)\n",
-					serverConfig.logFile,
-					strerror(errcode),
-					errcode);
-			}
+			loggingConfig["target"] = serverConfig.logFile;
 		}
 		if (serverConfig.fileDescriptorLogFile != NULL) {
-			Passenger::setFileDescriptorLogFile(serverConfig.fileDescriptorLogFile);
+			loggingConfig["file_descriptor_log_target"] =
+				serverConfig.fileDescriptorLogFile;
 		}
+
+		vector<ConfigKit::Error> errors;
+		LoggingKit::ConfigChangeRequest req;
+		bool ok;
+		try {
+			ok = LoggingKit::context->prepareConfigChange(loggingConfig,
+				errors, req);
+		} catch (const std::exception &e) {
+			fprintf(stderr, "ERROR: unable to configure logging system: %s\n", e.what());
+		}
+		if (ok) {
+			LoggingKit::context->commitConfigChange(req);
+		} else {
+			fprintf(stderr, "ERROR: unable to configuring logging system: %s\n",
+				ConfigKit::toString(errors).c_str());
+		}
+
 		m_hasModRewrite = UNKNOWN;
 		m_hasModDir = UNKNOWN;
 		m_hasModAutoIndex = UNKNOWN;
@@ -1288,11 +1287,18 @@ public:
 			const char *webServerDesc = ap_get_server_version();
 		#endif
 
+		ap_version_t version;
+		ap_get_server_revision(&version);
+		string webServerVersion = toString(version.major) + "." + toString(version.minor) + "." + toString(version.patch);
+		if (version.add_string != NULL) {
+			webServerVersion.append(version.add_string);
+		}
+
 		VariantMap params;
 		params
 			.setPid ("web_server_control_process_pid", getpid())
-			.setStrSet("web_server_config_files", getConfigFiles(s))
 			.set    ("server_software", webServerDesc)
+			.set    ("server_version", webServerVersion)
 			.setBool("multi_app", true)
 			.setBool("load_shell_envvars", true)
 			.set    ("file_descriptor_log_file", (serverConfig.fileDescriptorLogFile == NULL)
@@ -1300,6 +1306,8 @@ public:
 			.setInt	("socket_backlog", serverConfig.socketBacklog)
 			.set    ("data_buffer_dir", serverConfig.dataBufferDir)
 			.set    ("instance_registry_dir", serverConfig.instanceRegistryDir)
+			.setBool("disable_security_update_check", serverConfig.disableSecurityUpdateCheck)
+			.set    ("security_update_check_proxy", serverConfig.securityUpdateCheckProxy)
 			.setBool("user_switching", serverConfig.userSwitching)
 			.set    ("default_user", serverConfig.defaultUser)
 			.set    ("default_group", serverConfig.defaultGroup)
@@ -1565,8 +1573,8 @@ static Hooks *hooks = NULL;
 static apr_status_t
 destroy_hooks(void *arg) {
 	try {
-		this_thread::disable_interruption di;
-		this_thread::disable_syscall_interruption dsi;
+		boost::this_thread::disable_interruption di;
+		boost::this_thread::disable_syscall_interruption dsi;
 		P_DEBUG("Shutting down Phusion Passenger...");
 		delete hooks;
 		hooks = NULL;
@@ -1601,6 +1609,8 @@ init_module(apr_pool_t *pconf, apr_pool_t *plog, apr_pool_t *ptemp, server_rec *
 	 */
 	if (hooks == NULL) {
 		oxt::initialize();
+		LoggingKit::initialize();
+		SystemTime::initialize();
 	} else {
 		P_DEBUG("Restarting Phusion Passenger....");
 		delete hooks;
@@ -1613,13 +1623,13 @@ init_module(apr_pool_t *pconf, apr_pool_t *plog, apr_pool_t *ptemp, server_rec *
 			apr_pool_cleanup_null);
 		return OK;
 
-	} catch (const thread_interrupted &e) {
+	} catch (const boost::thread_interrupted &e) {
 		P_TRACE(2, "A system call was interrupted during mod_passenger "
 			"initialization. Apache might be restarting or shutting "
 			"down. Backtrace:\n" << e.backtrace());
 		return DECLINED;
 
-	} catch (const thread_resource_error &e) {
+	} catch (const boost::thread_resource_error &e) {
 		struct rlimit lim;
 		string pthread_threads_max;
 		int ret;
@@ -1736,4 +1746,3 @@ passenger_register_hooks(apr_pool_t *p) {
 /**
  * @}
  */
-
